@@ -31,7 +31,7 @@
 /**
  * SECTION:gdrive
  * @short_description: Virtual File System drive management
- * @include: gio.h
+ * @include: gio/gio.h
  * 
  * #GDrive - this represent a piece of hardware connected to the machine.
  * Its generally only created for removable hardware or hardware with
@@ -59,11 +59,11 @@ static void g_drive_class_init (gpointer g_class,
 GType
 g_drive_get_type (void)
 {
-  static GType drive_type = 0;
+  static volatile gsize g_define_type_id__volatile = 0;
 
-  if (! drive_type)
+  if (g_once_init_enter (&g_define_type_id__volatile))
     {
-      static const GTypeInfo drive_info =
+      const GTypeInfo drive_info =
       {
         sizeof (GDriveIface), /* class_size */
 	g_drive_base_init,   /* base_init */
@@ -75,15 +75,16 @@ g_drive_get_type (void)
 	0,              /* n_preallocs */
 	NULL
       };
-
-      drive_type =
+      GType g_define_type_id =
 	g_type_register_static (G_TYPE_INTERFACE, I_("GDrive"),
 				&drive_info, 0);
 
-      g_type_interface_add_prerequisite (drive_type, G_TYPE_OBJECT);
+      g_type_interface_add_prerequisite (g_define_type_id, G_TYPE_OBJECT);
+
+      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
     }
 
-  return drive_type;
+  return g_define_type_id__volatile;
 }
 
 static void
@@ -215,6 +216,9 @@ g_drive_has_volumes (GDrive *drive)
  * @drive: a #GDrive.
  * 
  * Get a list of mountable volumes for @drive.
+ *
+ * The returned list should be freed with g_list_free(), after
+ * its elements have been unreffed with g_object_unref().
  * 
  * Returns: #GList containing any #GVolume<!---->s on the given @drive.
  **/
@@ -474,5 +478,59 @@ g_drive_poll_for_media_finish (GDrive        *drive,
   return (* iface->poll_for_media_finish) (drive, result, error);
 }
 
+/**
+ * g_drive_get_identifier:
+ * @drive: a #GDrive
+ * @kind: the kind of identifier to return
+ *
+ * Gets the identifier of the given kind for @drive.
+ *
+ * Returns: a newly allocated string containing the
+ *   requested identfier, or %NULL if the #GDrive
+ *   doesn't have this kind of identifier
+ */
+char *
+g_drive_get_identifier (GDrive     *drive,
+			const char *kind)
+{
+  GDriveIface *iface;
+
+  g_return_val_if_fail (G_IS_DRIVE (drive), NULL);
+  g_return_val_if_fail (kind != NULL, NULL);
+
+  iface = G_DRIVE_GET_IFACE (drive);
+
+  if (iface->get_identifier == NULL)
+    return NULL;
+  
+  return (* iface->get_identifier) (drive, kind);
+}
+
+/**
+ * g_drive_enumerate_identifiers:
+ * @drive: a #GDrive
+ *
+ * Gets the kinds of identifiers that @drive has. 
+ * Use g_drive_get_identifer() to obtain the identifiers
+ * themselves.
+ *
+ * Returns: a %NULL-terminated array of strings containing
+ *   kinds of identifiers. Use g_strfreev() to free.
+ */
+char **
+g_drive_enumerate_identifiers (GDrive *drive)
+{
+  GDriveIface *iface;
+
+  g_return_val_if_fail (G_IS_DRIVE (drive), NULL);
+  iface = G_DRIVE_GET_IFACE (drive);
+
+  if (iface->enumerate_identifiers == NULL)
+    return NULL;
+  
+  return (* iface->enumerate_identifiers) (drive);
+}
+
+
 #define __G_DRIVE_C__
 #include "gioaliasdef.c"
